@@ -1,7 +1,7 @@
 """Assonant Axis data handler."""
 from typing import Union
 
-from ..types import TransformationType
+from ..enums import TransformationType
 from .data_field import DataField
 from .data_handler import DataHandler
 from .time_series import TimeSeries
@@ -14,6 +14,5 @@ class Axis(DataHandler):
     should be an array or TimeSeries.
     """
 
-    name: str
     transformation_type: TransformationType
     value: Union[DataField, TimeSeries]
